@@ -87,15 +87,30 @@ AudioPlayer::AudioPlayer(Type type, const QUrl& audioFile, float volume, float f
         return;
     }
 
-    mAudioPlayer = libvlc_media_player_new_from_media(media);
+    // It is necessary to use a libVLC media list in order to repeat audio files,
+    // since it doesn't seem to be possible to repeat an audio file using a simple
+    // libVLC media player.
+    mMediaList = libvlc_media_list_new(mAudioInstance);
+    libvlc_media_list_add_media(mMediaList, media);
     libvlc_media_release(media);
+    mAudioPlayer = libvlc_media_list_player_new(mAudioInstance);
     if (!mAudioPlayer)
+    {
+        mError = i18nc("@info", "Cannot initialize audio player");
+        qCCritical(KALARM_LOG) << "AudioPlayer: Error initializing audio list player";
+        return;
+    }
+    libvlc_media_list_player_set_media_list(mAudioPlayer, mMediaList);
+
+    libvlc_media_player_t* mediaPlayer = libvlc_media_player_new(mAudioInstance);
+    if (!mediaPlayer)
     {
         mError = i18nc("@info", "Cannot initialize audio player");
         qCCritical(KALARM_LOG) << "AudioPlayer: Error initializing audio player";
         return;
     }
-    libvlc_media_player_set_role(mAudioPlayer, libvlc_role_Notification);
+    libvlc_media_player_set_role(mediaPlayer, libvlc_role_Notification);
+    libvlc_media_list_player_set_media_player(mAudioPlayer, mediaPlayer);
 
     if (mVolume > 0)
     {
@@ -108,7 +123,9 @@ AudioPlayer::AudioPlayer(Type type, const QUrl& audioFile, float volume, float f
         }
         else
             mCurrentVolume = mVolume;
-        libvlc_audio_set_volume(mAudioPlayer, static_cast<int>(mCurrentVolume * 100));
+        libvlc_media_player_t* mediaPlayer = libvlc_media_list_player_get_media_player(mAudioPlayer);
+        if (mediaPlayer)
+            libvlc_audio_set_volume(mediaPlayer, static_cast<int>(mCurrentVolume * 100));
     }
 
     mStatus = Ready;
@@ -127,9 +144,17 @@ AudioPlayer::~AudioPlayer()
     }
     if (mAudioPlayer)
     {
-        libvlc_media_player_release(mAudioPlayer);
+        libvlc_media_player_t* mediaPlayer = libvlc_media_list_player_get_media_player(mAudioPlayer);
+        if (mediaPlayer)
+            libvlc_media_player_release(mediaPlayer);
+        libvlc_media_list_player_release(mAudioPlayer);
         mAudioPlayer = nullptr;
     }
+    if (mMediaList)
+    {
+        libvlc_media_list_release(mMediaList);
+        mMediaList = nullptr;
+    }
     if (mAudioInstance)
     {
         libvlc_release(mAudioInstance);
@@ -156,28 +181,36 @@ bool AudioPlayer::play()
         return false;
 
     qCDebug(KALARM_LOG) << "AudioPlayer::play";
-    libvlc_event_manager_t* eventManager = libvlc_media_player_event_manager(mAudioPlayer);
-    if (libvlc_event_attach(eventManager, libvlc_MediaPlayerStopped, &finish_callback, this))
+    if (!mPlayedAlready)
     {
-        qCWarning(KALARM_LOG) << "AudioPlayer: Error setting completion callback";
-        mCheckPlayTimer = new QTimer(this);
-        connect(mCheckPlayTimer, &QTimer::timeout, this, &AudioPlayer::checkPlay);
+        libvlc_media_player_t* mediaPlayer = libvlc_media_list_player_get_media_player(mAudioPlayer);
+        libvlc_event_manager_t* eventManager = libvlc_media_player_event_manager(mediaPlayer);
+        if (libvlc_event_attach(eventManager, libvlc_MediaPlayerStopped, &finish_callback, this))
+        {
+            qCWarning(KALARM_LOG) << "AudioPlayer: Error setting completion callback";
+            if (!mCheckPlayTimer)
+            {
+                mCheckPlayTimer = new QTimer(this);
+                connect(mCheckPlayTimer, &QTimer::timeout, this, &AudioPlayer::checkPlay);
+            }
+        }
+        libvlc_event_attach(eventManager, libvlc_MediaPlayerEncounteredError, &finish_callback, this);
     }
-    // Does the Error event need to be watched??
-    libvlc_event_attach(eventManager, libvlc_MediaPlayerEncounteredError, &finish_callback, this);
-
-    if (libvlc_media_player_play(mAudioPlayer) < 0)
+    if (libvlc_media_list_player_play_item_at_index(mAudioPlayer, 0) < 0)
     {
         mError = xi18nc("@info", "<para>Error playing audio file: <filename>%1</filename></para>", mFile);
         qCWarning(KALARM_LOG) << "AudioPlayer::play: Failed to play sound with VLC:" << mFile;
         Q_EMIT finished(false);
         return false;
     }
+    mPlayedAlready = true;
     if (mFadeTimer  &&  mVolume != mCurrentVolume)
     {
         mFadeStart = time(nullptr);
         mFadeTimer->start(1000);
     }
+    if (mCheckPlayTimer)
+        mCheckPlayTimer->start(1000);
     mStatus = Playing;
     return true;
 }
@@ -199,7 +232,9 @@ void AudioPlayer::fadeStep()
         }
         else
             mCurrentVolume = mFadeVolume + (mVolume - mFadeVolume) * elapsed / mFadeSeconds;
-        libvlc_audio_set_volume(mAudioPlayer, static_cast<int>(mCurrentVolume * 100));
+        libvlc_media_player_t* mediaPlayer = libvlc_media_list_player_get_media_player(mAudioPlayer);
+        if (mediaPlayer)
+            libvlc_audio_set_volume(mediaPlayer, static_cast<int>(mCurrentVolume * 100));
     }
 }
 
@@ -208,10 +243,11 @@ void AudioPlayer::fadeStep()
 */
 void AudioPlayer::checkPlay()
 {
-    if (!libvlc_media_player_is_playing(mAudioPlayer))
+    if (!libvlc_media_list_player_is_playing(mAudioPlayer))
     {
         playFinished(libvlc_MediaPlayerStopped);
-        mCheckPlayTimer->stop();
+        if (mCheckPlayTimer)
+            mCheckPlayTimer->stop();
     }
 }
 
@@ -221,8 +257,6 @@ void AudioPlayer::checkPlay()
 void AudioPlayer::finish_callback(const libvlc_event_t* event, void* userdata)
 {
     QMetaObject::invokeMethod(static_cast<AudioPlayer*>(userdata), "playFinished", Q_ARG(uint32_t, event->type));
-    if (event->type == libvlc_MediaPlayerEncounteredError)
-        qCWarning(KALARM_LOG) << "AudioPlayer: Error while playing";
 }
 
 /******************************************************************************
@@ -230,13 +264,15 @@ void AudioPlayer::finish_callback(const libvlc_event_t* event, void* userdata)
 */
 void AudioPlayer::playFinished(uint32_t event)
 {
-    qCDebug(KALARM_LOG) << "AudioPlayer::playFinished:" << mFile;
     mStatus = Ready;
     mFadeStart = 0;
+    if (mCheckPlayTimer)
+        mCheckPlayTimer->stop();
     bool result;
     switch (event)
     {
         case libvlc_MediaPlayerStopped:
+            qCDebug(KALARM_LOG) << "AudioPlayer::playFinished:" << mFile;
             result = true;
             break;
         default:
@@ -259,8 +295,10 @@ void AudioPlayer::playFinished(uint32_t event)
 void AudioPlayer::stop()
 {
     qCDebug(KALARM_LOG) << "AudioPlayer::stop";
-    if (mAudioPlayer  &&  libvlc_media_player_is_playing(mAudioPlayer))
-        libvlc_media_player_stop(mAudioPlayer);
+    if (mCheckPlayTimer)
+        mCheckPlayTimer->stop();
+    if (mAudioPlayer  &&  libvlc_media_list_player_is_playing(mAudioPlayer))
+        libvlc_media_list_player_stop(mAudioPlayer);
 }
 
 QString AudioPlayer::popError()
