@@ -21,21 +21,21 @@
 QCheckBox* FileDialog::mAppendCheck = nullptr;
 
 
-FileDialog::FileDialog(const QUrl& startDir, const QString& filter, QWidget* parent)
+FileDialog::FileDialog(const QUrl& startDir, const QList<KFileFilter>& filters, QWidget* parent)
     : KFileCustomDialog(parent)
 {
-    fileWidget()->setFilter(filter);
+    fileWidget()->setFilters(filters);
     fileWidget()->setStartDir(startDir);
 }
 
-QString FileDialog::getSaveFileName(const QUrl& dir, const QString& filter, QWidget* parent, const QString& caption, bool* append)
+QString FileDialog::getSaveFileName(const QUrl& dir, const QList<KFileFilter>& filters, QWidget* parent, const QString& caption, bool* append)
 {
     bool defaultDir = dir.isEmpty();
     bool specialDir = !defaultDir && dir.scheme() == QLatin1String("kfiledialog");
     // Use AutoQPointer to guard against crash on application exit while
     // the dialogue is still open. It prevents double deletion (both on
     // deletion of parent, and on return from this function).
-    AutoQPointer<FileDialog> dlg = new FileDialog(specialDir ? dir : QUrl(), filter, parent);
+    AutoQPointer<FileDialog> dlg = new FileDialog(specialDir ? dir : QUrl(), filters, parent);
     if (!specialDir && !defaultDir)
     {
         if (!dir.isLocalFile())
@@ -77,4 +77,6 @@ void FileDialog::appendToggled(bool ticked)
     fileWidget()->setConfirmOverwrite(!ticked);
 }
 
+#include "moc_filedialog.cpp"
+
 // vim: et sw=4:
